/**
 * Copyright (C) Altimetrik 2018. All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Altimetrik. You shall not disclose such Confidential Information
 * and shall use it only in accordance with the terms and conditions
 * entered into with Altimetrik.
 */

package com.altimetrik.playground.innovation.security;

import org.apache.commons.lang3.StringUtils;
import org.springframework.security.core.Authentication;

import com.altimetrik.playground.innovation.bean.Principal;

/**
 * AuthValidatorUtil Class.
 * @author Altimetrik Technologies
 */
public final class AuthValidatorUtil {

	/**
	 * Instantiates a new auth validator util.
	 */
	private AuthValidatorUtil() {
		// No Constructor.
	}

	/**
	 * Checks if is valid user.
	 *
	 * @param principal the principal
	 * @param userId the user id
	 * @return true, if is valid user
	 */
	public static boolean isValidUser(Principal principal, String userId) {
		if (StringUtils.isBlank(userId) || principal == null) {
			return false;
		}
		return (userId.equals(principal.getUserId()));
	}

	/**
	 * Checks if is valid user by user name.
	 *
	 * @param principal the principal
	 * @param userName the user name
	 * @return true, if is valid user by user name
	 */
	public static boolean isValidUserByUserName(Principal principal, String userName) {
		if (StringUtils.isBlank(userName) || principal == null) {
			return false;
		}
		return (userName.equals(principal.getUserName()));
	}

	/**
	 * Checks if is valid user.
	 *
	 * @param authentication the authentication
	 * @param userId the user id
	 * @return true, if is valid user
	 */
	public static boolean isValidUser(Authentication authentication, String userId) {
		return isValidUser(getPrincipal(authentication), userId);
	}

	/**
	 * Checks if is valid user by user name.
	 *
	 * @param authentication the authentication
	 * @param userName the user name
	 * @return true, if is valid user by user name
	 */
	public static boolean isValidUserByUserName(Authentication authentication, String userName) {
		return isValidUserByUserName(getPrincipal(authentication), userName);
	}

	/**
	 * Gets the principal.
	 *
	 * @param authentication the authentication
	 * @return the principal
	 */
	public static Principal getPrincipal(Authentication authentication) {
		if (authentication != null && authentication.getPrincipal() instanceof Principal) {
			return ((Principal) authentication.getPrincipal());
		}
		return null;
	}

	/**
	 * to get user name of the authenticated user.
	 * @param authentication
	 * @return
	 */
	public static String getUserName(Authentication authentication) {
		Principal principal = getPrincipal(authentication);
		if (principal != null) {
			return principal.getUserName();
		}
		return null;
	}

	/**
	 * to get the user id of the authenticated user.
	 * @param authentication
	 * @return
	 */
	public static String getUserId(Authentication authentication) {
		Principal principal = getPrincipal(authentication);
		if (principal != null) {
			return principal.getUserId();
		}
		return null;
	}

}
